******************************************************.
***** Count the NUMSTU for each school *****.
******************************************************.
GET
  FILE= 'E:\H Mioko\SACMEQ3\Main Data Quality\ZAM\merged_ZAM.SAV'.

FREQUENCIES
  VARIABLES=REGION DISTRICT
  /ORDER=  ANALYSIS .

string stratum (a3).
compute stratum=region.

SORT CASES BY
 idschool (A) .

AGGREGATE
  /OUTFILE='T:\MIOKO\SACMEQ3\Main Data Quality\ZAM\W1.sav'
  /BREAK=idschool stratum
  /numstu=N.

********************************************************.
***** Count the SCHPERST for each school *****.
********************************************************.
GET
  FILE='T:\MIOKO\SACMEQ3\Main Data Quality\ZAM\W1.SAV'.

compute countsch=1.
if numstu gt 25 countsch=2.

AGGREGATE
  /OUTFILE='T:\MIOKO\SACMEQ3\Main Data Quality\ZAM\W2.sav'
  /BREAK=stratum
  /sumnum=sum(numstu)
  /schperst= SUM(countsch).

*************************************************************.
***** Calculate the actual ENR6 for each school *****.
*************************************************************.
GET
  FILE='T:\MIOKO\SACMEQ3\Main Data Quality\ZAM\06_SIBK_ZAM_S3_26SEPT2007.SAV'.

string stratum (a3).
compute stratum=region.

string idschool (a9).
compute idschool=string(school,f9).

***** ZAM Special Cleaning *****.
if school=1942 spupgir6=0.
***** ZAM Special Cleaning *****.

compute enr6= spupboy6 +spupgir6.
formats enr6 (f4.0).

FILTER OFF.
USE ALL.
EXECUTE .

*** Make sure that no school has 0 enrolment ***.
FREQUENCIES
  VARIABLES=enr6 
  /ORDER=  ANALYSIS .

sort cases by   idschool (A) .

save outfile='T:\MIOKO\SACMEQ3\Main Data Quality\ZAM\W3.SAV' /keep stratum idschool enr6.

****************************************************************************.
***** Calculate the probability, raising factor, and pupil weight *****.
****************************************************************************.
GET
  FILE='T:\MIOKO\SACMEQ3\sampling\ZAM\ZAM_sel.sav'.

*** Check the actual name of the stratification for each country ***.
FREQUENCIES
  VARIABLES=REG
  /ORDER=  ANALYSIS .

*** ZAMBIA special change ***.
recode REG ('CENTRAL'='CEN') ('COPPERBELT'='COP') ('EASTERN'='EAS') ('LUAPULA'='LUA') ('LUSAKA'='LUS') ('NORTH WESTERN'='NEW')
 ('NORTHERN'='NOR') ('SOUTHERN'='SOU') ('WESTERN'='WES').
*** ZAMBIA special change ***.

string stratum (a3).
compute stratum=REG .

string idschool (a9).
compute idschool=str(idsch,f9).

sort cases by idschool (a).

MATCH FILES /FILE=*
 /FILE='T:\MIOKO\SACMEQ3\Main Data Quality\ZAM\W1.sav'
 /FILE='T:\MIOKO\SACMEQ3\Main Data Quality\ZAM\W3.sav'
 /BY  idschool.
EXECUTE.

sort cases by stratum (a).

*** Make sure that you have created ZAM_STR.sav ***.
MATCH FILES /FILE=*
 /TABLE='T:\MIOKO\SACMEQ3\Main Data Quality\ZAM\W2.sav'
 /TABLE='T:\MIOKO\SACMEQ3\sampling\ZAM\ZAM_STR.sav'
/BY stratum.
EXECUTE.

compute xnumstu=numstu.
if numstu gt 25 xnumstu=numstu/2.

***** ZAM Special Cleaning *****.
if missing(enr6) enr6=mos.
***** ZAM Special Cleaning *****.

****Check the achieved sample and population figures ****.
compute prob1=schperst*xnumstu/strsize.
compute RF1=1/prob1.
compute pweight1=RF1*2895/255581.

compute prob2=schperst*(mos/strsize)*(xnumstu/enr6).
compute RF2=1/prob2.

compute difenr=abs(mos-enr6).
compute difenr2=mos-enr6.

select if not(missing(numstu)).

****Make sure to use the correct field for the strata name ****.
sort cases by idschool (A).
Save outfile='T:\MIOKO\SACMEQ3\Main Data Quality\ZAM\W4.sav'
 /keep stratum REG idschool MOS strsize schperst enr6 difenr difenr2 numstu xnumstu prob1 RF1 pweight1 prob2 RF2 .

***** Check the weights before merging *****.
***** Copy the summary list to Excel and use it later for checking *****.
GET
  FILE='T:\MIOKO\SACMEQ3\Main Data Quality\ZAM\W4.SAV'.

sort cases by stratum (a) idschool (A).

****Make sure to use the correct field for the strata name ****.
SUMMARIZE
  /TABLES=stratum REG idschool MOS strsize schperst enr6 difenr difenr2 numstu xnumstu prob1 RF1 pweight1 prob2 RF2 
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE='Case Summaries'
  /MISSING=VARIABLE
  /CELLS=COUNT .

******************************************.
***** Merge the weight variables *****.
******************************************.
GET
  FILE= 'E:\H Mioko\SACMEQ3\Main Data Quality\ZAM\merged_ZAM.SAV'.

string stratum (a3).
compute stratum=region.

SORT CASES BY
 idschool (A) .

MATCH FILES /FILE=*
 /TABLE='T:\MIOKO\SACMEQ3\Main Data Quality\ZAM\W4.sav'
 /RENAME (stratum = d0)
 /BY idschool.
EXECUTE.

***** Checking whether the stratum information is consistent with sample *****.
USE ALL.
COMPUTE filter_$=(stratum ~= d0).
VARIABLE LABEL filter_$ 'stratum ~= d0 (FILTER)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE .

****Make sure to use the correct field for the strata name ****.
SUMMARIZE
  /TABLES=country region district school stratum d0 region 
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE='Discrepancies on stratum'
  /MISSING=VARIABLE
  /CELLS=COUNT .

FILTER OFF.
USE ALL.
EXECUTE .

********************* Run up to just above and weight by RF2 for a frequency *************************.
compute pweight2=RF2*2895/241846.5928359.
EXECUTE.

weight off.

variable labels
 MOS "WGT:/ Measure of Size during Sampling " 
/ STRSIZE "WGT:/ Strata Size " 
/ SCHPERST "WGT:/ School per stratum " 
/ ENR6 "WGT:/ Total enrolment of Grade 6 during Data collection " 
/ DIFENR "WGT:/ Difference between MOS and ENR6 " 
/ DIFENR2 "WGT:/ Absolute difference between MOS and ENR6 " 
/ NUMSTU "WGT:/ Number of students at each school " 
/ XNUMSTU "WGT:/ Theoritical Number of students at each school " 
/ PROB1 "WGT:/ Probability of a pupil being selected (for pweight1) " 
/ RF1 "WGT:/ Raising Factor (for pweight1) " 
/ PWEIGHT1 "WGT:/ PUPIL WEIGHT (SUMWGT=#PUPIL/COUNTRY during sampling " 
/ PROB2 "WGT:/ Probability of a pupil being selected (for pweight2) " 
/ RF2 "WGT:/ Raising Factor (for pweight2) " 
/ PWEIGHT2 "WGT:/ PUPIL WEIGHT (SUMWGT=#PUPIL/COUNTRY during data collection " 
.

Save outfile= 'E:\H Mioko\SACMEQ3\Main Data Quality\ZAM\weighted_ZAM.sav' /drop filter_$ d0 .

***** Check the weighted data *****.
GET
  FILE= 'E:\H Mioko\SACMEQ3\Main Data Quality\ZAM\weighted_ZAM.SAV'.

title 'Weighted by RF1'.

WEIGHT
  BY RF1 .

FREQUENCIES
  VARIABLES=stratum 
  /ORDER  ANALYSIS .

title 'Weighted by pweight1'.

WEIGHT
  BY pweight1 .

FREQUENCIES
  VARIABLES=stratum
  /ORDER  ANALYSIS .

title 'Weighted by RF2'.

WEIGHT
  BY RF2 .

FREQUENCIES
  VARIABLES=stratum 
  /ORDER  ANALYSIS .
FILTER OFF.

title 'Weighted by pweight2'.

WEIGHT
  BY pweight2 .

FREQUENCIES
  VARIABLES=stratum
  /ORDER  ANALYSIS .

***** Checking PWEIGHT2 *****.

GET
  FILE= 'E:\H Mioko\SACMEQ3\Main Data Quality\ZAM\weighted_ZAM.SAV'.

compute w2numstu=pweight2*xnumstu.
formats w2numstu (F8.5).

AGGREGATE
  /OUTFILE='T:\MIOKO\SACMEQ3\Main Data Quality\ZAM\W5.SAV'
  /BREAK=idschool
  /nwtdscl=first(w2numstu).

GET
  FILE= 'E:\H Mioko\SACMEQ3\Main Data Quality\ZAM\weighted_ZAM.SAV'.

sort cases by idschool (a).

MATCH FILES /FILE=*
 /TABLE='T:\MIOKO\SACMEQ3\Main Data Quality\ZAM\W5.SAV'
 /BY idschool.
EXECUTE.

compute checkwt=schperst*(mos/strsize)*(nwtdscl/enr6).
execute.
formats checkwt (f8.5).

FREQUENCIES
  VARIABLES=checkwt 
  /ORDER  ANALYSIS .


